FedoraForum.org - Fedora Support Forums and Community
Page 1 of 2 12 LastLast
Results 1 to 15 of 16
  1. #1
    Join Date
    Jul 2005
    Posts
    50
    Mentioned
    0 Post(s)
    Tagged
    0 Thread(s)

    F10 (and F9): Want to disable the GDM "face browser" user list

    I find the lack of being able to edit the list of users shown at initial login extremely frustrating. A search of these forums will show that I am not alone.

    I think it's possible to turn off the "face browser" entirely, which would at least be better than the current situation. But I haven't figured out how. I think it would be something like this:

    $ gconf-editor
    apps/gdm/simple-greeter
    check disable_user_list

    I tried this from root with no effect. I searched every file in /etc/gdm and /usr/share/gdm for "user_list" without a hit.

    Perhaps the gdm user must be the one to run gconf-editor. I tried that (no doubt a big no-no) by setting the gdm account's shell to bash and running gconf-editor. However, gconf-editor can't read any of the settings, instead giving error messages about not being able to read networked configuration or possibly stale NFS links. That makes no sense, my machine does not have, and has never had, anything served or mounted over NFS (or samba or anything else). Just local files on the local harddrive (and the occasional USB stick or CD/DVD).

    In any case, if anyone knows how to turn off the face browser so that users simply type their usernames, I'd appreciate it if he/she posted the instructions in a reply.

  2. #2
    Join Date
    Jul 2008
    Posts
    10
    Mentioned
    0 Post(s)
    Tagged
    0 Thread(s)
    I updated F9 to F10 with Gnome. I then installed KDE packages, then deleted GDM. I run from KDE, using the Gnome apps I like. It also solves the graphical root login BS. The Gnome Nazis have gone too far.

    Not a fix but it works.

  3. #3
    Join Date
    Jul 2005
    Posts
    50
    Mentioned
    0 Post(s)
    Tagged
    0 Thread(s)
    This isn't a criticism of Gnome: they're not denying a gdmsetup, it just hasn't been implemented. If anything, it's a criticism of Fedora--I believe another distro updated Gnome w/o updating gdm. Perhaps mixing different versions of Gnome and gdm is a lot of work, or perhaps it has other problems, I don't know. But given the choices that have been made, I'd sure like some assistance in "making do" until there's a real solution.

    I skipped F9 because of this, but I can't stay on F8 forever. In fact, I believe updates will cease in a month. So I'm moving to F10, and am seriously in want of a work-around. Just disabling the face browser completely would be enough.

  4. #4
    Join Date
    Sep 2007
    Posts
    4
    Mentioned
    0 Post(s)
    Tagged
    0 Thread(s)
    I agree. Replacing key parts of the distribution with incomplete alternatives is bad practice. I understand Fedora wants to try new things, but at least have the basic features of the original present before you force a new version on your users. By cutting off support of Fedora 8, users now have to choose between staying with Fedora 8 without security updates, switching to Fedora 10 with fewer features and switching to a distribution that makes wiser security decisions.

    Turning off the face-browser is a requirement for the switch from Fedora 8 to Fedora 10 at my location. The face browser is a ridiculous feature to begin with. The ability for an unauthenticated user to enumerate accounts on the system is a security hole in the eyes of some. For a system with over 100 user accounts (for instance, systems that use LDAP authentication) it's also a large inconvenience. And since new Fedora releases are destined to become RHEL releases down the line, this is just more work that has to be done before these broken releases are ready for enterprise environments.

  5. #5
    Join Date
    Sep 2007
    Posts
    4
    Mentioned
    0 Post(s)
    Tagged
    0 Thread(s)
    You can disable the face-browser with this command (using sudo or as root):

    Code:
    gconftool-2 --direct --config-source xml:readwrite:/etc/gconf/gconf.xml.defaults --type bool --set /apps/gdm/simple-greeter/disable_user_list true

  6. #6
    Join Date
    Jul 2005
    Posts
    50
    Mentioned
    0 Post(s)
    Tagged
    0 Thread(s)
    gconftool-2 --direct --config-source xml:readwrite:/etc/gconf/gconf.xml.defaults --type bool --set /apps/gdm/simple-greeter/disable_user_list true
    Many thanks!

    I was just logging in to post my solution. I think yours is better, but I'll post mine anyways. Add the following to /var/lib/gdm/.gconf/apps/gdm/simple-greeter/%gconf.xml:
    Code:
    <?xml version="1.0"?>
      <gconf>
        <entry name="disable_user_list" mtime="1227900586" type="bool" value="true">
        </entry>
      </gconf>

  7. #7
    sdhjml Guest
    Many thanks for the post - I need to move to Fedora 10 due to F8 EOL as well and the user display is a security finding. The above posts worked just great.

    So am I to understand that gdmsetup will eventually be available?

    Thanks Again.

  8. #8
    Join Date
    Jun 2004
    Posts
    40
    Mentioned
    0 Post(s)
    Tagged
    0 Thread(s)
    No luck for Fedora 9. It doesn't have that gconf setting. It is also not listed on the Gnome specs at http://live.gnome.org/GDM/2.22/Configuration. Hopefully, this will be implemented for Fedora 9 soon.

  9. #9
    Join Date
    Mar 2006
    Posts
    2,206
    Mentioned
    28 Post(s)
    Tagged
    0 Thread(s)
    I can't remember who, but I think it was leigh123 who provided an rpm to regress to the F8 greeter for gnome. I think if you search for his name, gdm and greeter you will find it. I did it for my server that is F10.
    jbkt23
    Thinkpads Depends on era T23 - X2xx
    AMD & Intel Boxes

  10. #10
    Join Date
    May 2005
    Posts
    27
    Mentioned
    0 Post(s)
    Tagged
    0 Thread(s)
    Thanks very much for the command to disable the infamous face browser. The inability to configure this was a major problem. It prevented us from going to FC9. One minor remaining, aesthetic question is whether it is possible to eliminate the "Other" box that still appears? Beginning people find it confusing. Experienced people find it ugly. The ideal would just be a simple two-entry panel with boxes for Username and Password, or in other words, clean, functional simplicity. It's difficult to comprehend the reasoning that forced the face browser interface on us. It's like the Fedora/Gnome people went on vacation for a while and Microsoft briefly took over! Hoping for clearer thinking in 2009...

  11. #11
    Join Date
    Aug 2005
    Location
    Ann Arbor
    Age
    59
    Posts
    3,947
    Mentioned
    0 Post(s)
    Tagged
    0 Thread(s)
    i just use kdm to boot into gnome
    -- if you have kde installed also
    add a file called "desktop" to /etc/sysconfig
    Code:
    su -
    gedit /etc/sysconfig/desktop
    and add this to it
    Code:
    DESKTOP="GNOME"
    DISPLAYMANAGER="KDE"
    then reboot
    OpenSUSE 13.2-64bit & Scientific Linux 6.6-64bit ( fedora 4 to 11) and 20 on KVM
    My Celestia Downloads

    h t t p ://celestiamotherlode.net/catalog/show_creator_details.php?creator_id=10

  12. #12
    MrKing Guest

    Disable "face browser"in f10

    You can also do:
    Applications > System Tools > Configuration Editor > Apps > gdm > simple-greeter
    then tick the box against "disable_user_list".
    Pity it won't also change the "Other..." text at the login screen.

  13. #13
    Join Date
    Feb 2009
    Posts
    3
    Mentioned
    0 Post(s)
    Tagged
    0 Thread(s)
    Quote Originally Posted by MrKing
    You can also do:
    Applications > System Tools > Configuration Editor > Apps > gdm > simple-greeter
    then tick the box against "disable_user_list".
    Pity it won't also change the "Other..." text at the login screen.
    gconf-editor /apps/gdm/simplegreeter/disable_user_list does not have effect. i may be wrong but i believe that has already been addressed in the thread.

  14. #14
    Join Date
    Aug 2009
    Posts
    1
    Mentioned
    0 Post(s)
    Tagged
    0 Thread(s)

    Still having issues?

    Is anyone still having issues from this?

    RedHat created the new version of gdm. When I was stabilizing fedora 9 (when it was in beta) for deployment in my college's computer science labs I ran into this huge usability issue. The original bug report that led to the key being added to the gconf:
    https://bugzilla.redhat.com/show_bug.cgi?id=445449

    ==================================
    There were 2 problems with redhat's fix:
    1. it still stats people's home dirs, which can cause lots of mounts on NFS
    2. "Other.." Confuses people, I Changed it to "Click Here To Enter Username..."
    It is a hard coded string, to change it you need to hack into the source.

    I have 2 small patches, if you guys are brave with compiling gdm from source. It was made to work on a early version of f10's gdm (the rawhide build right after fedora 9 came out):
    http://www.joshlange.net/priv/gdmhackpatch/

    ===================================

    The issue that most of you have seems to be the lack of knowledge about the gconf ;-). The gconf exists as 4 seperate trees, that are merged together: user, system, defaults, and mandatory trees.

    I personally added this option to the mandatory and system trees for our labs, along with a few other useful ones:

    ################################################## #
    #make the internet button work for old gconf's
    ln -sf /usr/bin/firefox /usr/bin/htmlview

    #hmm we think we got this. Running strace -fe open firefox shows lots of
    #file activity around extensions...
    #CAUSES FIREFOX TO TAKE 2+ MINUTES ON NFS HOME DIRS!
    rm -rf /usr/lib/firefox*/extensions/langpack-*

    #matlab tries to use netscape!
    [ -e /usr/bin/netscape ] || ln /usr/bin/htmlview /usr/bin/netscape


    #GDM OPTIONS
    #gnome shutdown is no longer chained to gdm shutdown options
    #this is a new option, from a gnome bug
    gconftool-2 --direct --config-source xml:readwrite:/etc/gconf/gconf.xml.mandatory --type bool --set "/apps/gdm/simple-greeter/disable_user_list" "true"

    gconftool-2 --direct --config-source xml:readwrite:/etc/gconf/gconf.xml.mandatory --type string --set "/apps/gdm/simple-greeter/banner_message_text" "Welcome to the Cal Poly Computer Science Labs!"

    gconftool-2 --direct --config-source xml:readwrite:/etc/gconf/gconf.xml.mandatory --type bool --set "/apps/gdm/simple-greeter/banner_message_enable" "true"

    #MANDITORY SYSTEM WIDE GNOME CONF
    gconftool-2 --direct --config-source xml:readwrite:/etc/gconf/gconf.xml.mandatory --type bool --set "/apps/gnome-power-manager/can_hibernate" "false"

    gconftool-2 --direct --config-source xml:readwrite:/etc/gconf/gconf.xml.mandatory --type bool --set "/apps/gnome-power-manager/can_suspend" "false"

    gconftool-2 --direct --config-source xml:readwrite:/etc/gconf/gconf.xml.mandatory --type bool --set "/desktop/gnome/sound/event_sounds" "false"

    gconftool-2 --direct --config-source xml:readwrite:/etc/gconf/gconf.xml.mandatory --type bool --set "/desktop/gnome/lockdown/disable_user_switching" "true"

    gconftool-2 --direct --config-source xml:readwrite:/etc/gconf/gconf.xml.mandatory --type bool --set "/apps/gnome-screensaver/logout_enabled" "true"

    gconftool-2 --direct --config-source xml:readwrite:/etc/gconf/gconf.xml.mandatory --type bool --set "/apps/gnome-screens
    aver/user_switch_enabled" "false"
    gconftool-2 --direct --config-source xml:readwrite:/etc/gconf/gconf.xml.mandatory --type int --set "/apps/gnome-screensa
    ver/logout_delay" "0"

    gconftool-2 --direct --config-source xml:readwrite:/etc/gconf/gconf.xml.mandatory --type bool --set "/apps/gnome-screensaver/user_switch_enabled" "false"

    gconftool-2 --direct --config-source xml:readwrite:/etc/gconf/gconf.xml.mandatory --type int --set "/apps/gnome-screensa
    ver/logout_delay" "0"

    #gconftool-2 --direct --config-source xml:readwrite:/etc/gconf/gconf.xml.mandatory --type string --set "/apps/gnome-screensaver/logout_command" 'gnome-session-save --kill --silent'

    #works around a gnome session bug (gnome screensaver started before the session is active)
    gconftool-2 --direct --config-source xml:readwrite:/etc/gconf/gconf.xml.mandatory --type string --set "/apps/gnome-screensaver/logout_command" 'killall -HUP gnome-session'

    #CHANGE THE DEFAULTS
    gconftool-2 --direct --config-source xml:readwrite:/etc/gconf/gconf.xml.defaults --type int --set "/apps/gnome-screensaver/idle_delay" '4'

    gconftool-2 --direct --config-source xml:readwrite:/etc/gconf/gconf.xml.defaults --type string --set "/desktop/gnome/interface/gtk_theme" "Glossy"

    gconftool-2 --direct --config-source xml:readwrite:/etc/gconf/gconf.xml.defaults --type string --set "/apps/metacity/general/theme" "Glossy"

    gconftool-2 --direct --config-source xml:readwrite:/etc/gconf/gconf.xml.defaults --type string --set "/desktop/gnome/interface/icon_theme" "Fedora"

    gconftool-2 --direct --config-source xml:readwrite:/etc/gconf/gconf.xml.defaults --type bool --set "/apps/nautilus/preferences/always_use_location_entry" "true"

    gconftool-2 --direct --config-source xml:readwrite:/etc/gconf/gconf.xml.defaults --type bool --set "/apps/nautilus/preferences/always_use_browser" "true"


    #default firefox homepage, lets pull it off the fedora one, no one cares about the release notes.

    HOMEPAGE="http://www.google.com/"
    FIRSTBOOTPAGE="http://wiki.csc.calpoly.edu/start/wiki/FrequentlyAskedQuestions"

    for dpath in /usr/lib/firefox*; do
    [ -d "$dpath" ] || continue
    #change "first boot" defaults
    JSPATH="$dpath/defaults/preferences/all-redhat.js"
    [ -f "$JSPATH" ] && sed -i 's#pref("browser.startup.homepage", "http://start.fedoraproject.org/");#pref("browser.star
    tup.homepage", "'"$HOMEPAGE"'");#' "$JSPATH"
    [ -f "$JSPATH" ] && sed -i 's#pref("browser.startup.homepage", "http://wiki.csc.calpoly.edu/start/wiki/FrequentlyAske
    dQuestions");#pref("browser.startup.homepage", "'"$HOMEPAGE"'");#' "$JSPATH"
    [ -f "$JSPATH" ] && sed -i 's#pref("startup.homepage_welcome_url", "http://fedoraproject.org/static/firefox/");#pref(
    "startup.homepage_welcome_url", "'"$FIRSTBOOTPAGE"'");#' "$JSPATH"
    [ -f "$JSPATH" ] && sed -i 's#.*startup.homepage_override_url.*##' "$JSPATH"
    #change home pages
    for i in 'browser.startup.homepage=' 'browser.startup.homepage_reset='; do
    [ -f "$dpath/browserconfig.properties" ] && sed -i "s#^$i.*\$#${i}$HOMEPAGE#" "$dpath/browserconfig.properties"
    done
    done
    Last edited by sillygates; 1st September 2009 at 06:38 AM.

  15. #15
    Join Date
    Apr 2010
    Location
    USA
    Age
    62
    Posts
    40
    Mentioned
    0 Post(s)
    Tagged
    0 Thread(s)

    Re: Still having issues?

    Quote Originally Posted by sillygates
    Is anyone still having issues from this?

    RedHat created the new version of gdm. When I was stabilizing fedora 9 (when it was in beta) for deployment in my college's computer science labs I ran into this huge usability issue. The original bug report that led to the key being added to the gconf:
    https://bugzilla.redhat.com/show_bug.cgi?id=445449

    ==================================
    There were 2 problems with redhat's fix:
    1. it still stats people's home dirs, which can cause lots of mounts on NFS
    2. "Other.." Confuses people, I Changed it to "Click Here To Enter Username..."
    It is a hard coded string, to change it you need to hack into the source.

    I have 2 small patches, if you guys are brave with compiling gdm from source. It was made to work on a early version of f10's gdm (the rawhide build right after fedora 9 came out):
    http://www.joshlange.net/priv/gdmhackpatch/

    ===================================

    The issue that most of you have seems to be the lack of knowledge about the gconf ;-). The gconf exists as 4 seperate trees, that are merged together: user, system, defaults, and mandatory trees.

    I personally added this option to the mandatory and system trees for our labs, along with a few other useful ones:

    ################################################## #
    #make the internet button work for old gconf's
    ln -sf /usr/bin/firefox /usr/bin/htmlview

    #hmm we think we got this. Running strace -fe open firefox shows lots of
    #file activity around extensions...
    #CAUSES FIREFOX TO TAKE 2+ MINUTES ON NFS HOME DIRS!
    rm -rf /usr/lib/firefox*/extensions/langpack-*

    #matlab tries to use netscape!
    [ -e /usr/bin/netscape ] || ln /usr/bin/htmlview /usr/bin/netscape


    #GDM OPTIONS
    #gnome shutdown is no longer chained to gdm shutdown options
    #this is a new option, from a gnome bug
    gconftool-2 --direct --config-source xml:readwrite:/etc/gconf/gconf.xml.mandatory --type bool --set "/apps/gdm/simple-greeter/disable_user_list" "true"

    gconftool-2 --direct --config-source xml:readwrite:/etc/gconf/gconf.xml.mandatory --type string --set "/apps/gdm/simple-greeter/banner_message_text" "Welcome to the Cal Poly Computer Science Labs!"

    gconftool-2 --direct --config-source xml:readwrite:/etc/gconf/gconf.xml.mandatory --type bool --set "/apps/gdm/simple-greeter/banner_message_enable" "true"

    #MANDITORY SYSTEM WIDE GNOME CONF
    gconftool-2 --direct --config-source xml:readwrite:/etc/gconf/gconf.xml.mandatory --type bool --set "/apps/gnome-power-manager/can_hibernate" "false"

    gconftool-2 --direct --config-source xml:readwrite:/etc/gconf/gconf.xml.mandatory --type bool --set "/apps/gnome-power-manager/can_suspend" "false"

    gconftool-2 --direct --config-source xml:readwrite:/etc/gconf/gconf.xml.mandatory --type bool --set "/desktop/gnome/sound/event_sounds" "false"

    gconftool-2 --direct --config-source xml:readwrite:/etc/gconf/gconf.xml.mandatory --type bool --set "/desktop/gnome/lockdown/disable_user_switching" "true"

    gconftool-2 --direct --config-source xml:readwrite:/etc/gconf/gconf.xml.mandatory --type bool --set "/apps/gnome-screensaver/logout_enabled" "true"

    gconftool-2 --direct --config-source xml:readwrite:/etc/gconf/gconf.xml.mandatory --type bool --set "/apps/gnome-screens
    aver/user_switch_enabled" "false"
    gconftool-2 --direct --config-source xml:readwrite:/etc/gconf/gconf.xml.mandatory --type int --set "/apps/gnome-screensa
    ver/logout_delay" "0"

    gconftool-2 --direct --config-source xml:readwrite:/etc/gconf/gconf.xml.mandatory --type bool --set "/apps/gnome-screensaver/user_switch_enabled" "false"

    gconftool-2 --direct --config-source xml:readwrite:/etc/gconf/gconf.xml.mandatory --type int --set "/apps/gnome-screensa
    ver/logout_delay" "0"

    #gconftool-2 --direct --config-source xml:readwrite:/etc/gconf/gconf.xml.mandatory --type string --set "/apps/gnome-screensaver/logout_command" 'gnome-session-save --kill --silent'

    #works around a gnome session bug (gnome screensaver started before the session is active)
    gconftool-2 --direct --config-source xml:readwrite:/etc/gconf/gconf.xml.mandatory --type string --set "/apps/gnome-screensaver/logout_command" 'killall -HUP gnome-session'

    #CHANGE THE DEFAULTS
    gconftool-2 --direct --config-source xml:readwrite:/etc/gconf/gconf.xml.defaults --type int --set "/apps/gnome-screensaver/idle_delay" '4'

    gconftool-2 --direct --config-source xml:readwrite:/etc/gconf/gconf.xml.defaults --type string --set "/desktop/gnome/interface/gtk_theme" "Glossy"

    gconftool-2 --direct --config-source xml:readwrite:/etc/gconf/gconf.xml.defaults --type string --set "/apps/metacity/general/theme" "Glossy"

    gconftool-2 --direct --config-source xml:readwrite:/etc/gconf/gconf.xml.defaults --type string --set "/desktop/gnome/interface/icon_theme" "Fedora"

    gconftool-2 --direct --config-source xml:readwrite:/etc/gconf/gconf.xml.defaults --type bool --set "/apps/nautilus/preferences/always_use_location_entry" "true"

    gconftool-2 --direct --config-source xml:readwrite:/etc/gconf/gconf.xml.defaults --type bool --set "/apps/nautilus/preferences/always_use_browser" "true"


    #default firefox homepage, lets pull it off the fedora one, no one cares about the release notes.

    HOMEPAGE="http://www.google.com/"
    FIRSTBOOTPAGE="http://wiki.csc.calpoly.edu/start/wiki/FrequentlyAskedQuestions"

    for dpath in /usr/lib/firefox*; do
    [ -d "$dpath" ] || continue
    #change "first boot" defaults
    JSPATH="$dpath/defaults/preferences/all-redhat.js"
    [ -f "$JSPATH" ] && sed -i 's#pref("browser.startup.homepage", "http://start.fedoraproject.org/");#pref("browser.star
    tup.homepage", "'"$HOMEPAGE"'");#' "$JSPATH"
    [ -f "$JSPATH" ] && sed -i 's#pref("browser.startup.homepage", "http://wiki.csc.calpoly.edu/start/wiki/FrequentlyAske
    dQuestions");#pref("browser.startup.homepage", "'"$HOMEPAGE"'");#' "$JSPATH"
    [ -f "$JSPATH" ] && sed -i 's#pref("startup.homepage_welcome_url", "http://fedoraproject.org/static/firefox/");#pref(
    "startup.homepage_welcome_url", "'"$FIRSTBOOTPAGE"'");#' "$JSPATH"
    [ -f "$JSPATH" ] && sed -i 's#.*startup.homepage_override_url.*##' "$JSPATH"
    #change home pages
    for i in 'browser.startup.homepage=' 'browser.startup.homepage_reset='; do
    [ -f "$dpath/browserconfig.properties" ] && sed -i "s#^$i.*\$#${i}$HOMEPAGE#" "$dpath/browserconfig.properties"
    done
    done
    Thank you very much for this information, it helped me to understand a bit more about gconf

Page 1 of 2 12 LastLast

Similar Threads

  1. Disable "Switch User" dialog
    By taozhyn in forum Using Fedora
    Replies: 1
    Last Post: 28th August 2008, 02:58 AM
  2. "fstab"ed in the face by ntfs-3g
    By ajinxa in forum Using Fedora
    Replies: 16
    Last Post: 2nd December 2006, 03:51 PM
  3. Replies: 0
    Last Post: 23rd May 2005, 04:59 AM
  4. Replies: 1
    Last Post: 19th March 2005, 04:20 PM
  5. Browser for "normal" user recommendation?
    By joeuser in forum Using Fedora
    Replies: 5
    Last Post: 14th October 2004, 08:21 PM

Tags for this Thread

Posting Permissions

  • You may not post new threads
  • You may not post replies
  • You may not post attachments
  • You may not edit your posts
  •